#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2021-03-21

from typing import Mapping, Dict, List, Tuple, NamedTuple

from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import (
    DiscoveryResult,
    CheckResult,
    StringTable,
)

from cmk.base.plugins.agent_based.agent_based_api.v1 import (
    register,
    Service,
    check_levels,
    SNMPTree,
    contains,
)


#
# sample string_table
# [[['41']]]
#
def parse_cisco_asyncos_cpu(string_table: List[StringTable]) -> int:
    try:
        return int(string_table[0][0][0])
    except KeyError:
        pass


def discovery_cisco_asyncos_cpu(section: int) -> DiscoveryResult:
    yield Service()


def check_cisco_asyncos_cpu(params, section: int) -> CheckResult:
    def render_percent(value) -> str:
        return '%s%%' % value

    yield from check_levels(
        section,
        label='CPU utilization in the last minute',
        levels_upper=params.get('util', None),
        metric_name='util',  # if params.get('output_metrics') else None,
        render_func=render_percent,
    )


register.snmp_section(
    name='cisco_asyncos_cpu',
    parse_function=parse_cisco_asyncos_cpu,
    fetch=[
        SNMPTree(
            base='.1.3.6.1.4.1.15497.1.1.1',
            oids=[
                '2'  # ASYNCOS-MAIL-MIB::perCentCPUUtilization
            ]
        ),
    ],
    detect=contains('.1.3.6.1.2.1.1.1.0', 'AsyncOS'),
)

register.check_plugin(
    name='cisco_asyncos_cpu',
    service_name='CPU Utilization 1 min',
    discovery_function=discovery_cisco_asyncos_cpu,
    check_function=check_cisco_asyncos_cpu,
    check_default_parameters={},
    check_ruleset_name='cpu_utilization'
)
