#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2021-03-21
#
# .1.3.6.1.4.1.15497.1.1.1.1.0 = INTEGER: 0
# .1.3.6.1.4.1.15497.1.1.1.7.0 = INTEGER: 1
#
# ASYNCOS-MAIL-MIB::perCentMemoryUtilization.0 = INTEGER: 0
# ASYNCOS-MAIL-MIB::memoryAvailabilityStatus.0 = INTEGER: memoryAvailable(1)
#
# sample info
# [[u'0', u'1']]
#

from typing import Mapping, Dict, List, Tuple, NamedTuple

from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import (
    DiscoveryResult,
    CheckResult,
    StringTable,
)

from cmk.base.plugins.agent_based.agent_based_api.v1 import (
    register,
    Service,
    check_levels,
    SNMPTree,
    contains,
)


# factory_settings['cisco_asyncos_mem_default_levels'] = {
#         'levels':(80.0, 90.0),
#     }

#
# [[['48']]
#
def parse_cisco_asyncos_mem(string_table: List[StringTable]) -> int:
    try:
        return int(string_table[0][0][0])
    except KeyError:
        pass


def discovery_cisco_asyncos_mem(section: int) -> DiscoveryResult:
    yield Service()


def check_cisco_asyncos_mem(params, section: int) -> CheckResult:
    def render_percent(value) -> str:
        return '%s%%' % value

    yield from check_levels(
        section,
        label='Memory utilization',
        levels_upper=params.get('util', None),
        metric_name='util',
        render_func=render_percent,
    )


register.snmp_section(
    name='cisco_asyncos_mem',
    parse_function=parse_cisco_asyncos_mem,
    fetch=[
        SNMPTree(
            base='.1.3.6.1.4.1.15497.1.1.1',
            oids=[
                '1',  # perCentMemoryUtilization
            ]
        ),
    ],
    detect=contains('.1.3.6.1.2.1.1.1.0', 'AsyncOS'),
)

register.check_plugin(
    name='cisco_asyncos_mem',
    service_name='Memory utilization',
    discovery_function=discovery_cisco_asyncos_mem,
    check_function=check_cisco_asyncos_mem,
    check_default_parameters={},
    check_ruleset_name='memory'
)
