#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
#
from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    TextAscii,
    ListOfStrings,
    Tuple,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_cisco_asyncos_license():
    return Dictionary(elements=[
        ('features_ignore',
         ListOfStrings(
             title=_('Update features to ignore'),
             orientation='vertical',
             help=_('there will be no warning/critical if this features are not updated'
                    'Examples: geo_countries, timezones, etc.'),
         )
         ),
        ('failedLevel',
         Tuple(
             title=_('Levels for failed attempts'),
             elements=[
                 Integer(title=_('Warning'), default_value=5, unit=_('# of failed attempts')),
                 Integer(title=_('Critical'), default_value=10, unit=_('# of failed attempts')),
             ])),
    ])


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='cisco_asyncos_update',
        group=RulespecGroupCheckParametersNetworking,
        item_spec=lambda: TextAscii(title=_('Cisco AsyncOS update'), ),
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_cisco_asyncos_update,
        title=lambda: _('Cisco AsyncOS update'),
    ))
